==> ejc-probuilddiary-api-3.0.0-20220916.063707-4-sources.jar: com/ejianc/business/probuilddiary/project/vo/ProjectLogInformationVO.java <==
package com.ejianc.business.probuilddiary.project.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 项目日志-工程资料归档及会议情况（资料员）
 *
 * @author baipengyan
 */
public class ProjectLogInformationVO extends BaseVO {
	private static final long serialVersionUID = 1706764164520293816L;

	private Long personId; // 个人日志id
	private Long informMoldId; // 工作类型id
	private String informMoldName; // 工作类型名称
	private String informMoldCode; // 工作类型编码
	private String informationMemo; // 工作描述
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private String fileType; // 文件类型


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getInformMoldId() {
		return informMoldId;
	}

	public void setInformMoldId(Long informMoldId) {
		this.informMoldId = informMoldId;
	}

	public String getInformMoldName() {
		return informMoldName;
	}

	public void setInformMoldName(String informMoldName) {
		this.informMoldName = informMoldName;
	}

	public String getInformMoldCode() {
		return informMoldCode;
	}

	public void setInformMoldCode(String informMoldCode) {
		this.informMoldCode = informMoldCode;
	}

	public String getInformationMemo() {
		return informationMemo;
	}

	public void setInformationMemo(String informationMemo) {
		this.informationMemo = informationMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}
}

==> ejc-probuilddiary-api-3.0.0-20220919.091701-11-sources.jar: com/ejianc/business/probuilddiary/project/vo/ProjectLogInformationVO.java <==
package com.ejianc.business.probuilddiary.project.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 项目日志-工程资料归档及会议情况（资料员）
 *
 * @author baipengyan
 */
public class ProjectLogInformationVO extends BaseVO {
	private static final long serialVersionUID = 1706764164520293816L;

	private Long personId; // 个人日志id
	private Long informMoldId; // 工作类型id
	private String informMoldName; // 工作类型名称
	private String informMoldCode; // 工作类型编码
	private String informationMemo; // 工作描述
	private Long commitUserId; // 提交人id
	private String commitUserCode; // 提交人账号
	private String commitUserName; // 提交人名称
	private Date commitDate; // 提交日期
	private Long projectLogId; // 项目日志id
	private String fileType; // 文件类型
	private Boolean updateFlag; // 更新状态


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getInformMoldId() {
		return informMoldId;
	}

	@ReferDeserialTransfer
	public void setInformMoldId(Long informMoldId) {
		this.informMoldId = informMoldId;
	}

	public String getInformMoldName() {
		return informMoldName;
	}

	public void setInformMoldName(String informMoldName) {
		this.informMoldName = informMoldName;
	}

	public String getInformMoldCode() {
		return informMoldCode;
	}

	public void setInformMoldCode(String informMoldCode) {
		this.informMoldCode = informMoldCode;
	}

	public String getInformationMemo() {
		return informationMemo;
	}

	public void setInformationMemo(String informationMemo) {
		this.informationMemo = informationMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public Boolean getUpdateFlag() {
		return updateFlag;
	}

	public void setUpdateFlag(Boolean updateFlag) {
		this.updateFlag = updateFlag;
	}
}
